pub struct MetaColumns {
pub exported_at: bool,
pub row_hash: bool,
}Fields
exported_at: boolrow_hash: boolTrait Implementations
Sourceimpl Clone for MetaColumns
impl Clone for MetaColumns
Sourcefn clone(&self) -> MetaColumns
fn clone(&self) -> MetaColumns
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetaColumns
impl Debug for MetaColumns
Sourceimpl Default for MetaColumns
impl Default for MetaColumns
Sourcefn default() -> MetaColumns
fn default() -> MetaColumns
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MetaColumns
impl<'de> Deserialize<'de> for MetaColumns
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetaColumns
impl JsonSchema for MetaColumns
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MetaColumns
impl RefUnwindSafe for MetaColumns
impl Send for MetaColumns
impl Sync for MetaColumns
impl Unpin for MetaColumns
impl UnsafeUnpin for MetaColumns
impl UnwindSafe for MetaColumns