pub struct NotificationsConfig {
pub slack: Option<SlackConfig>,
}Fields
slack: Option<SlackConfig>Trait Implementations
Sourceimpl Clone for NotificationsConfig
impl Clone for NotificationsConfig
Sourcefn clone(&self) -> NotificationsConfig
fn clone(&self) -> NotificationsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationsConfig
impl Debug for NotificationsConfig
Sourceimpl<'de> Deserialize<'de> for NotificationsConfig
impl<'de> Deserialize<'de> for NotificationsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NotificationsConfig
impl JsonSchema for NotificationsConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NotificationsConfig
impl RefUnwindSafe for NotificationsConfig
impl Send for NotificationsConfig
impl Sync for NotificationsConfig
impl Unpin for NotificationsConfig
impl UnsafeUnpin for NotificationsConfig
impl UnwindSafe for NotificationsConfig