pub struct SlackConfig {
pub webhook_url: Option<String>,
pub webhook_url_env: Option<String>,
pub on: Vec<NotifyEvent>,
}Fields
webhook_url: Option<String>webhook_url_env: Option<String>on: Vec<NotifyEvent>Trait Implementations
Sourceimpl Clone for SlackConfig
impl Clone for SlackConfig
Sourcefn clone(&self) -> SlackConfig
fn clone(&self) -> SlackConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SlackConfig
impl Debug for SlackConfig
Sourceimpl<'de> Deserialize<'de> for SlackConfig
impl<'de> Deserialize<'de> for SlackConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SlackConfig
impl JsonSchema for SlackConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SlackConfig
impl RefUnwindSafe for SlackConfig
impl Send for SlackConfig
impl Sync for SlackConfig
impl Unpin for SlackConfig
impl UnsafeUnpin for SlackConfig
impl UnwindSafe for SlackConfig