init

Function init 

pub fn init()
Initialize the kernel: set up the arch layer, discover #[rivet::task] (cooperative) tasks, and spawn the async executor as the lowest-priority preemptive task. Call spawn_ptask! for any additional preemptive tasks after this, then call run.