pub fn dropped_frames() -> usizeExpand description
Number of frames dropped so far because the ring was full (or logging
hadn’t been initialized yet — i.e. called before crate::init).
pub fn dropped_frames() -> usizeNumber of frames dropped so far because the ring was full (or logging
hadn’t been initialized yet — i.e. called before crate::init).