macro_rules! println {
() => { ... };
($($arg:tt)*) => { ... };
}Expand description
Write formatted text to the debug console, followed by a newline.
macro_rules! println {
() => { ... };
($($arg:tt)*) => { ... };
}Write formatted text to the debug console, followed by a newline.