Export target compatibility checks (roadmap 16).
Validates that an Arrow type produced by Rivet will load into the target warehouse as the expected type. Currently supports BigQuery.
BigQuery numeric limits (as of 2025): NUMERIC — precision 1–29, scale 0–9 BIGNUMERIC — precision 1–76, scale 0–38
Structs
- Target
Compat - One column’s compatibility result against a target.
Enums
- Export
Target - A supported downstream warehouse target.
- Target
Status - Status of a column’s Arrow type against a specific target.
Functions
- check_
target_ compat - Check whether
arrow_type(the type Rivet will write into Parquet) will produce the expected type when loaded intotarget.